==============================================================
 :mod:`xoeuf.models.extensions` -- Extensions to Odoo models.
==============================================================

.. automodule:: xoeuf.models.extensions

.. autofunction:: get_writer(model, [cr, uid, ids, context=None])

.. autofunction:: get_creator(model, [cr, uid, context=None])

.. autofunction:: get_treeview_action(self, **options)
